@@ -623,7 +623,15 @@ class Horde_Icalendar
                                 }
                             }
                         }
-                        $params[$paramName] = $paramValue;
+                        if (isset($params[$paramName])) {
+                            if (is_array($params[$paramName])) {
+                                $params[$paramName][] = $paramValue;
+                            } else {
+                                $params[$paramName] = array($params[$paramName], $paramValue);
+                            }
+                        } else {
+                            $params[$paramName] = $paramValue;
+                        }
                     }
                 }
 
@@ -942,7 +950,9 @@ class Horde_Icalendar
             case 'DUE':
             case 'AALARM':
             case 'RECURRENCE-ID':
-                $floating = $base == 'STANDARD' || $base == 'DAYLIGHT';
+                $floating = $base == 'STANDARD'
+                    || $base == 'DAYLIGHT'
+                    || isset($params['TZID']);
                 if (isset($params['VALUE'])) {
                     if ($params['VALUE'] == 'DATE') {
                         // VCALENDAR 1.0 uses T000000 - T235959 for all day events:
